==> Release_Version_2.2_for_v1.5.zip: Release Version 2.2 for v1.5/DCS.openbeta/Mods/tech/OH-6A_Weaponpack/Weapons/#_ AGM-114K.lua <==
-- Hellfires


declare_loadout(
{
	category   			= CAT_MISSILES, 
	CLSID    				= "OH6_AGM_114K_R1", 
  attribute  			= {wsType_Weapon,wsType_Missile,wsType_Container,WSTYPE_PLACEHOLDER},
  wsTypeOfWeapon		= "weapons.missiles.AGM_114K",
	Picture   			= "OH58D_AGM_114.png",  
	displayName  			= "1xAGM-114K",
	Cx_pil				=	0.001,
	Weight     			= 45.18+42.18+3.65+2.04, -- Hellfire K 45.18 kg -- Launcher 42.18 kg -- bras armé 3.65 kg -- cablage 2.04 kg
	Count 				= 1,
    settings 				= Get_LGU_GUISettings_Preset("WGU59"),	  
	Elements  = 
	{
	{
		--Position	=	{0.2689, 0.0, 0.0}, -- marche pas ici ?
		ShapeName	=	"OH58D_HRACK_R",
		IsAdapter   =   true,
	},
	{
		--Position	=	{0.4081,	0.4399,	0.212}, -- ext relatif position pylon
		--Position	=	{fwd/aft,	-up/down,	L/R}, -- ext relatif position pylon
		Position	=	{0.15,	-0.1,	0.165}, -- ext relatif position pylon			--- (0.35,	-0.1,	0.165},
		ShapeName	=	"AGM-114K",
		Rotation    =   {0.0,0.0,0.0},
	},
	-- {
		-- Position	=	{0.403,	-0.13,	-0.17}, -- int relatif position pylon
		-- ShapeName	=	"OH58D_AGM114K",
		-- Rotation    =   {0.0,0.0,0.0},
	-- },
	},
})

declare_loadout(
 {
  category   			= CAT_MISSILES,
  CLSID    				= "OH6_AGM_114K_R",
  attribute  			= {wsType_Weapon,wsType_Missile,wsType_Container,WSTYPE_PLACEHOLDER},
  wsTypeOfWeapon		= "weapons.missiles.AGM_114K",
  Picture   			= "OH58D_AGM_114.png",
  displayName  			= "2xAGM-114K",
  Cx_pil				=	0.001,
  Weight     			= (2*45.18)+42.18+3.65+2.04, -- Hellfire K 45.18 kg -- Launcher 42.18 kg -- bras armé 3.65 kg -- cablage 2.04 kg
  Count 				= 2,
  settings 				= Get_LGU_GUISettings_Preset("WGU59"),
  Elements  = 
  {
	{
		--Position	=	{0.2689, 0.0, 0.0}, -- marche pas ici ?
		ShapeName	=	"OH58D_HRACK_R",
		IsAdapter   =   true,
	},
	{
		--Position	=	{fwd/aft,	-up/down,	L/R}, -- ext relatif position pylon				
		--Position	=	{0.4081,	0.4399,	0.212}, -- ext relatif position pylon
		Position	=	{0.15,	-0.1,	0.165}, -- ext relatif position pylon
		ShapeName	=	"AGM-114K",
		Rotation    =   {0.0,0.0,0.0},
	},
	{
		Position	=	{0.15,	-0.1,	-0.17}, -- int relatif position pylon
		ShapeName	=	"AGM-114K",
		Rotation    =   {0.0,0.0,0.0},
	},
  },
 }
)

declare_loadout(
 {
  category   			= CAT_MISSILES,
  CLSID    				= "OH6_AGM_114K_L1",
  attribute  			= {wsType_Weapon,wsType_Missile,wsType_Container,WSTYPE_PLACEHOLDER},
  wsTypeOfWeapon		= "weapons.missiles.AGM_114K",
  Picture   			= "OH58D_AGM_114.png",
  displayName  			= "1xAGM-114K",
  Cx_pil				= 0.001,
  Weight     			= 45.18+42.18+3.65+2.04, -- Hellfire K 45.18 kg -- Launcher 42.18 kg -- bras armé 3.65 kg -- cablage 2.04 kg
  Count 				= 1,
  settings 				= Get_LGU_GUISettings_Preset("WGU59"),     
  Elements  = 
  {
	{
		--Position	=	{0,	0,	0},
		ShapeName	=	"OH58D_HRACK_L",
		IsAdapter   =   true,
	},
	{
		Position	=	{0.15,	-0.1,	-0.165}, -- ext relatif position pylon
		ShapeName	=	"AGM-114K",
		Rotation    =   {0.0,0.0,0.0},
	},
	-- {
		-- Position	=	{0.403,	-0.13,	0.2}, -- int relatif position pylon
		-- ShapeName	=	"OH58D_AGM114K",
		-- Rotation    =   {0.0,0.0,0.0},
	-- },
  },
 }
)

declare_loadout(
 {
  category   			= CAT_MISSILES,
  CLSID    				= "OH6_AGM_114K_L",   
  attribute  			= {wsType_Weapon,wsType_Missile,wsType_Container,WSTYPE_PLACEHOLDER},
  wsTypeOfWeapon		= "weapons.missiles.AGM_114K",
  Picture   			= "OH58D_AGM_114.png",
  displayName  			= "2xAGM-114K",
  Cx_pil				=	0.001,
  Weight     			= (2*45.18)+42.18+3.65+2.04, -- Hellfire K 45.18 kg -- Launcher 42.18 kg -- bras armé 3.65 kg -- cablage 2.04 kg
  Count 				= 2,
  settings 				= Get_LGU_GUISettings_Preset("WGU59"), 
  Elements  = 
  {
	{
		--Position	=	{0,	0,	0},
		ShapeName	=	"OH58D_HRACK_L",
		IsAdapter   =   true,
	},
	{
		Position	=	{0.15,	-0.1,	-0.165}, -- ext relatif position pylon
		ShapeName	=	"AGM-114K",
		Rotation    =   {0.0,0.0,0.0},
	},
	{
		Position	=	{0.15,	-0.1,	0.17}, -- int relatif position pylon 0.20
		ShapeName	=	"AGM-114K",
		Rotation    =   {0.0,0.0,0.0},   
	},
  },
 }
)

==> Release_Version_2.4_for_v1.6.zip: Release Version 2.4 for v1.6/DCS.openbeta/Mods/tech/OH-6A_Weaponpack/Weapons/#_ AGM-114K.lua <==
-- Hellfires


declare_loadout(
{
	category   			= CAT_MISSILES, 
	CLSID    				= "OH6_AGM_114K_R1",   
  attribute  			= {wsType_Weapon,wsType_Missile,wsType_Container,WSTYPE_PLACEHOLDER},
  wsTypeOfWeapon		= "weapons.missiles.AGM_114K",
	Picture   			= "OH58D_AGM_114.png",  
	displayName  			= "1xAGM-114K (Laser-Guided)",
	Cx_pil				=	0.001,
	Weight     			= (1*45.18)+42.18+3.65+2.04, -- Hellfire K 45.18 kg -- Launcher 42.18 kg -- bras armé 3.65 kg -- cablage 2.04 kg
	Count 				= 1,
    settings 				= Get_LGU_GUISettings_Preset("WGU59"),	     
	Elements  = 
	{
	{
		--Position	=	{0.2689, 0.0, 0.0}, -- marche pas ici ?
		ShapeName	=	"OH58D_HRACK_R",
		IsAdapter   =   true,
	},
	{
		--Position	=	{0.4081,	0.4399,	0.212}, -- ext relatif position pylon
		--Position	=	{fwd/aft,	-up/down,	L/R}, -- ext relatif position pylon
		Position	=	{0.15,	-0.1,	0.165}, -- ext relatif position pylon			--- (0.35,	-0.1,	0.165},
		ShapeName	=	"AGM-114K",
		Rotation    =   {0.0,0.0,0.0},
	},
	-- {
		-- Position	=	{0.403,	-0.13,	-0.17}, -- int relatif position pylon
		-- ShapeName	=	"OH58D_AGM114K",
		-- Rotation    =   {0.0,0.0,0.0},
	-- },
	},
})

declare_loadout(
 {
  category   			= CAT_MISSILES,
  CLSID    				= "OH6_AGM_114K_R",
  attribute  			= {wsType_Weapon,wsType_Missile,wsType_Container,WSTYPE_PLACEHOLDER},
  wsTypeOfWeapon		= "weapons.missiles.AGM_114K",
  Picture   			= "OH58D_AGM_114.png",
  displayName  			= "2xAGM-114K (Laser-Guided)",
  Cx_pil				=	0.001,
  Weight     			= (2*45.18)+42.18+3.65+2.04, -- Hellfire K 45.18 kg -- Launcher 42.18 kg -- bras armé 3.65 kg -- cablage 2.04 kg
  Count 				= 2,
  settings 				= Get_LGU_GUISettings_Preset("WGU59"),
  Elements  = 
  {
	{
		--Position	=	{0.2689, 0.0, 0.0}, -- marche pas ici ?
		ShapeName	=	"OH58D_HRACK_R",
		IsAdapter   =   true,
	},
	{
		--Position	=	{fwd/aft,	-up/down,	L/R}, -- ext relatif position pylon				
		--Position	=	{0.4081,	0.4399,	0.212}, -- ext relatif position pylon
		Position	=	{0.15,	-0.1,	0.165}, -- ext relatif position pylon
		ShapeName	=	"AGM-114K",
		Rotation    =   {0.0,0.0,0.0},
	},
	{
		Position	=	{0.15,	-0.1,	-0.17}, -- int relatif position pylon
		ShapeName	=	"AGM-114K",
		Rotation    =   {0.0,0.0,0.0},
	},
  },
 }
)


declare_loadout(
 {
  category   			= CAT_MISSILES,
  CLSID    				= "AH6_AGM_114K_R4",
  attribute  			= {wsType_Weapon,wsType_Missile,wsType_Container,WSTYPE_PLACEHOLDER},
  wsTypeOfWeapon		= "weapons.missiles.AGM_114K",
  Picture   			= "OH58D_AGM_114.png",
  displayName  			= "4xAGM-114K (Laser-Guided)",
  Cx_pil				=	0.001,
  Weight     			= (4*45.18)+42.18+3.65+2.04, -- Hellfire K 45.18 kg -- Launcher 42.18 kg -- bras armé 3.65 kg -- cablage 2.04 kg
  Count 				= 4,
  settings 				= Get_LGU_GUISettings_Preset("WGU59"),
  Elements  = 
  {
	{
		--Position	=	{0.2689, 0.0, 0.0}, -- marche pas ici ?  
		ShapeName	=	"M299", --OH58D_HRACK_R
		IsAdapter   =   true,
	},
	{
		--Position	=	{fwd/aft,	-up/down,	L/R}, -- ext relatif position pylon				
		--Position	=	{0.4081,	0.4399,	0.212}, -- ext relatif position pylon
		Position	=	{0.15,	0.05,	0.165}, -- ext relatif position pylon
		ShapeName	=	"AGM-114K",
		Rotation    =   {0.0,0.0,0.0},
	},
	{
		Position	=	{0.15,	0.05,	-0.17}, -- int relatif position pylon  
		ShapeName	=	"AGM-114K",
		Rotation    =   {0.0,0.0,0.0},
	},	
	{
		Position	=	{0.15,	-0.25,	-0.135}, -- int relatif position pylon
		ShapeName	=	"AGM-114K",
		Rotation    =   {0.0,0.0,0.0},
	},	
	{
		Position	=	{0.15,	-0.25,	0.135}, -- int relatif position pylon
		ShapeName	=	"AGM-114K",
		Rotation    =   {0.0,0.0,0.0},
	},	
  },
 }
)


declare_loadout(
 {
  category   			= CAT_MISSILES,
  CLSID    				= "OH6_AGM_114K_L1",
  attribute  			= {wsType_Weapon,wsType_Missile,wsType_Container,WSTYPE_PLACEHOLDER},
  wsTypeOfWeapon		= "weapons.missiles.AGM_114K",
  Picture   			= "OH58D_AGM_114.png",
  displayName  			= "1xAGM-114K (Laser-Guided)",
  Cx_pil				= 0.001,
  Weight     			= (1*45.18)+42.18+3.65+2.04, -- Hellfire K 45.18 kg -- Launcher 42.18 kg -- bras armé 3.65 kg -- cablage 2.04 kg
  Count 				= 1,
  settings 				= Get_LGU_GUISettings_Preset("WGU59"),     
  Elements  = 
  {
	{
		--Position	=	{0,	0,	0},
		ShapeName	=	"OH58D_HRACK_L",
		IsAdapter   =   true,
	},
	{
		Position	=	{0.15,	-0.1,	-0.165}, -- ext relatif position pylon
		ShapeName	=	"AGM-114K",
		Rotation    =   {0.0,0.0,0.0},
	},
	-- {
		-- Position	=	{0.403,	-0.13,	0.2}, -- int relatif position pylon
		-- ShapeName	=	"OH58D_AGM114K",
		-- Rotation    =   {0.0,0.0,0.0},
	-- },
  },
 }
)

declare_loadout(
 {
  category   			= CAT_MISSILES,
  CLSID    				= "OH6_AGM_114K_L",   
  attribute  			= {wsType_Weapon,wsType_Missile,wsType_Container,WSTYPE_PLACEHOLDER},
  wsTypeOfWeapon		= "weapons.missiles.AGM_114K",
  Picture   			= "OH58D_AGM_114.png",
  displayName  			= "2xAGM-114K (Laser-Guided)",  
  Cx_pil				=	0.001,
  Weight     			= (2*45.18)+42.18+3.65+2.04, -- Hellfire K 45.18 kg -- Launcher 42.18 kg -- bras armé 3.65 kg -- cablage 2.04 kg
  Count 				= 2,
  settings 				= Get_LGU_GUISettings_Preset("WGU59"), 
  Elements  = 
  {
	{
		--Position	=	{0,	0,	0},
		ShapeName	=	"OH58D_HRACK_L",
		IsAdapter   =   true,
	},
	{
		Position	=	{0.15,	-0.1,	-0.165}, -- ext relatif position pylon
		ShapeName	=	"AGM-114K",
		Rotation    =   {0.0,0.0,0.0},
	},
	{
		Position	=	{0.15,	-0.1,	0.17}, -- int relatif position pylon 0.20
		ShapeName	=	"AGM-114K",
		Rotation    =   {0.0,0.0,0.0},   
	},
  },
 }
)


declare_loadout(
 {
  category   			= CAT_MISSILES,
  CLSID    				= "AH6_AGM_114K_L4",     
  attribute  			= {wsType_Weapon,wsType_Missile,wsType_Container,WSTYPE_PLACEHOLDER},   
  wsTypeOfWeapon		= "weapons.missiles.AGM_114K",
  Picture   			= "OH58D_AGM_114.png",
  displayName  			= "4xAGM-114K (Laser-Guided)", 
  Cx_pil				=	0.001,
  Weight     			= (4*45.18)+42.18+3.65+2.04, -- Hellfire K 45.18 kg -- Launcher 42.18 kg -- bras armé 3.65 kg -- cablage 2.04 kg
  Count 				= 4,
  settings 				= Get_LGU_GUISettings_Preset("WGU59"), 
  Elements  = 
  {
	{
		--Position	=	{0,	0,	0},
		ShapeName	=	"M299", --OH58D_HRACK_L
		IsAdapter   =   true,
	},
	{
		Position	=	{0.15,	0.05,	-0.165}, -- ext relatif position pylon  
		ShapeName	=	"AGM-114K",
		Rotation    =   {0.0,0.0,0.0},
	},
	{
		Position	=	{0.15,	0.05,	0.17}, -- int relatif position pylon 0.20
		ShapeName	=	"AGM-114K",
		Rotation    =   {0.0,0.0,0.0},   
	},
	{
		Position	=	{0.15,	-0.25,	-0.135}, -- int relatif position pylon 0.20
		ShapeName	=	"AGM-114K",
		Rotation    =   {0.0,0.0,0.0},   
	},
	{
		Position	=	{0.15,	-0.25,	0.135}, -- int relatif position pylon 0.20   
		ShapeName	=	"AGM-114K",
		Rotation    =   {0.0,0.0,0.0},           
	},	
  },
 }
)
